@@ -179,12 +179,12 @@ const char* vala_ccode_include_directive_get_filename (ValaCCodeIncludeDirective
 
 
 void vala_ccode_include_directive_set_filename (ValaCCodeIncludeDirective* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_filename = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2_);
 }
 
 
