@@ -27,6 +27,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gee.h>
+#include <float.h>
+#include <math.h>
 
 
 #define VALA_TYPE_CODE_NODE (vala_code_node_get_type ())
