@@ -20,19 +20,69 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <vala/valascope.h>
-#include <gee/list.h>
-#include <gee/hashmap.h>
-#include <gee/arraylist.h>
-#include <gee/collection.h>
-#include <gee/readonlymap.h>
-#include <vala/valasymbol.h>
-#include <vala/valareport.h>
-#include <vala/valasourcereference.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <gee.h>
+#include <stdlib.h>
+#include <string.h>
 #include <gobject/gvaluecollector.h>
 
 
+#define VALA_TYPE_SCOPE (vala_scope_get_type ())
+#define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
+#define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
+#define VALA_IS_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SCOPE))
+#define VALA_IS_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SCOPE))
+#define VALA_SCOPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SCOPE, ValaScopeClass))
 
+typedef struct _ValaScope ValaScope;
+typedef struct _ValaScopeClass ValaScopeClass;
+typedef struct _ValaScopePrivate ValaScopePrivate;
+
+#define VALA_TYPE_CODE_NODE (vala_code_node_get_type ())
+#define VALA_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_NODE, ValaCodeNode))
+#define VALA_CODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
+#define VALA_IS_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_NODE))
+#define VALA_IS_CODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_NODE))
+#define VALA_CODE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
+
+typedef struct _ValaCodeNode ValaCodeNode;
+typedef struct _ValaCodeNodeClass ValaCodeNodeClass;
+
+#define VALA_TYPE_SYMBOL (vala_symbol_get_type ())
+#define VALA_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SYMBOL, ValaSymbol))
+#define VALA_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SYMBOL, ValaSymbolClass))
+#define VALA_IS_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SYMBOL))
+#define VALA_IS_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SYMBOL))
+#define VALA_SYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SYMBOL, ValaSymbolClass))
+
+typedef struct _ValaSymbol ValaSymbol;
+typedef struct _ValaSymbolClass ValaSymbolClass;
+
+#define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
+#define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
+#define VALA_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
+#define VALA_IS_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SOURCE_REFERENCE))
+#define VALA_IS_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SOURCE_REFERENCE))
+#define VALA_SOURCE_REFERENCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
+
+typedef struct _ValaSourceReference ValaSourceReference;
+typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+typedef struct _ValaParamSpecScope ValaParamSpecScope;
+
+/**
+ * Represents a part of the symbol tree.
+ */
+struct _ValaScope {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	ValaScopePrivate * priv;
+};
+
+struct _ValaScopeClass {
+	GTypeClass parent_class;
+	void (*finalize) (ValaScope *self);
+};
 
 struct _ValaScopePrivate {
 	ValaSymbol* _owner;
@@ -41,10 +91,53 @@ struct _ValaScopePrivate {
 	GeeList* anonymous_members;
 };
 
+struct _ValaParamSpecScope {
+	GParamSpec parent_instance;
+};
+
+
+
+gpointer vala_scope_ref (gpointer instance);
+void vala_scope_unref (gpointer instance);
+GParamSpec* vala_param_spec_scope (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_scope (GValue* value, gpointer v_object);
+gpointer vala_value_get_scope (const GValue* value);
+GType vala_scope_get_type (void);
+gpointer vala_code_node_ref (gpointer instance);
+void vala_code_node_unref (gpointer instance);
+GParamSpec* vala_param_spec_code_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_code_node (GValue* value, gpointer v_object);
+gpointer vala_value_get_code_node (const GValue* value);
+GType vala_code_node_get_type (void);
+GType vala_symbol_get_type (void);
 #define VALA_SCOPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SCOPE, ValaScopePrivate))
 enum  {
 	VALA_SCOPE_DUMMY_PROPERTY
 };
+void vala_scope_set_owner (ValaScope* self, ValaSymbol* value);
+ValaScope* vala_scope_new (ValaSymbol* owner);
+ValaScope* vala_scope_construct (GType object_type, ValaSymbol* owner);
+ValaScope* vala_scope_new (ValaSymbol* owner);
+ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name);
+void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
+ValaSymbol* vala_scope_get_owner (ValaScope* self);
+gpointer vala_source_reference_ref (gpointer instance);
+void vala_source_reference_unref (gpointer instance);
+GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_source_reference (GValue* value, gpointer v_object);
+gpointer vala_value_get_source_reference (const GValue* value);
+GType vala_source_reference_get_type (void);
+void vala_report_error (ValaSourceReference* source, const char* message);
+ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
+char* vala_symbol_get_full_name (ValaSymbol* self);
+void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value);
+void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym);
+void vala_scope_remove (ValaScope* self, const char* name);
+gboolean vala_symbol_get_active (ValaSymbol* self);
+ValaScope* vala_scope_get_parent_scope (ValaScope* self);
+gboolean vala_scope_is_subscope_of (ValaScope* self, ValaScope* scope);
+GeeMap* vala_scope_get_symbol_table (ValaScope* self);
+void vala_scope_set_parent_scope (ValaScope* self, ValaScope* value);
 static gpointer vala_scope_parent_class = NULL;
 static void vala_scope_finalize (ValaScope* obj);
 
@@ -80,31 +173,31 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 	g_return_if_fail (sym != NULL);
 	if (name != NULL) {
 		if (self->priv->symbol_table == NULL) {
-			GeeMap* _tmp0;
-			_tmp0 = NULL;
-			self->priv->symbol_table = (_tmp0 = (GeeMap*) gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_str_hash, g_str_equal, g_direct_equal), (self->priv->symbol_table == NULL) ? NULL : (self->priv->symbol_table = (gee_collection_object_unref (self->priv->symbol_table), NULL)), _tmp0);
+			GeeMap* _tmp0_;
+			_tmp0_ = NULL;
+			self->priv->symbol_table = (_tmp0_ = (GeeMap*) gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_str_hash, g_str_equal, g_direct_equal), (self->priv->symbol_table == NULL) ? NULL : (self->priv->symbol_table = (gee_collection_object_unref (self->priv->symbol_table), NULL)), _tmp0_);
 		} else {
-			ValaSymbol* _tmp1;
-			gboolean _tmp2;
-			_tmp1 = NULL;
-			if ((_tmp2 = (_tmp1 = vala_scope_lookup (self, name)) != NULL, (_tmp1 == NULL) ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)), _tmp2)) {
-				char* _tmp4;
-				char* _tmp3;
+			ValaSymbol* _tmp1_;
+			gboolean _tmp2_;
+			_tmp1_ = NULL;
+			if ((_tmp2_ = (_tmp1_ = vala_scope_lookup (self, name)) != NULL, (_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL)), _tmp2_)) {
+				char* _tmp4_;
+				char* _tmp3_;
 				vala_code_node_set_error ((ValaCodeNode*) self->priv->_owner, TRUE);
-				_tmp4 = NULL;
-				_tmp3 = NULL;
-				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) sym), _tmp4 = g_strdup_printf ("`%s' already contains a definition for `%s'", _tmp3 = vala_symbol_get_full_name (self->priv->_owner), name));
-				_tmp4 = (g_free (_tmp4), NULL);
-				_tmp3 = (g_free (_tmp3), NULL);
+				_tmp4_ = NULL;
+				_tmp3_ = NULL;
+				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) sym), _tmp4_ = g_strdup_printf ("`%s' already contains a definition for `%s'", _tmp3_ = vala_symbol_get_full_name (self->priv->_owner), name));
+				_tmp4_ = (g_free (_tmp4_), NULL);
+				_tmp3_ = (g_free (_tmp3_), NULL);
 				return;
 			}
 		}
 		gee_map_set (self->priv->symbol_table, (const char*) name, sym);
 	} else {
 		if (self->priv->anonymous_members == NULL) {
-			GeeList* _tmp5;
-			_tmp5 = NULL;
-			self->priv->anonymous_members = (_tmp5 = (GeeList*) gee_array_list_new (VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal), (self->priv->anonymous_members == NULL) ? NULL : (self->priv->anonymous_members = (gee_collection_object_unref (self->priv->anonymous_members), NULL)), _tmp5);
+			GeeList* _tmp5_;
+			_tmp5_ = NULL;
+			self->priv->anonymous_members = (_tmp5_ = (GeeList*) gee_array_list_new (VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal), (self->priv->anonymous_members == NULL) ? NULL : (self->priv->anonymous_members = (gee_collection_object_unref (self->priv->anonymous_members), NULL)), _tmp5_);
 		}
 		gee_collection_add ((GeeCollection*) self->priv->anonymous_members, sym);
 	}
@@ -128,23 +221,23 @@ void vala_scope_remove (ValaScope* self, const char* name) {
  */
 ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name) {
 	ValaSymbol* sym;
-	gboolean _tmp1;
+	gboolean _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	if (self->priv->symbol_table == NULL) {
 		return NULL;
 	}
 	sym = (ValaSymbol*) gee_map_get (self->priv->symbol_table, name);
-	_tmp1 = FALSE;
+	_tmp1_ = FALSE;
 	if (sym != NULL) {
-		_tmp1 = !vala_symbol_get_active (sym);
+		_tmp1_ = !vala_symbol_get_active (sym);
 	} else {
-		_tmp1 = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp1) {
-		ValaSymbol* _tmp2;
-		_tmp2 = NULL;
-		sym = (_tmp2 = NULL, (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp2);
+	if (_tmp1_) {
+		ValaSymbol* _tmp2_;
+		_tmp2_ = NULL;
+		sym = (_tmp2_ = NULL, (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp2_);
 	}
 	return sym;
 }
