@@ -359,6 +359,9 @@ ValaDelegate* vala_delegate_construct (GType object_type, const char* name, Vala
 GType vala_typesymbol_get_type (void);
 GType vala_delegate_get_type (void);
 void vala_delegate_set_has_target (ValaDelegate* self, gboolean value);
+GType vala_symbol_accessibility_get_type (void);
+void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value);
+void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value);
 ValaDataType* vala_data_type_copy (ValaDataType* self);
 void vala_data_type_set_value_owned (ValaDataType* self, gboolean value);
 void vala_data_type_set_nullable (ValaDataType* self, gboolean value);
@@ -387,9 +390,7 @@ gboolean vala_signal_get_is_virtual (ValaSignal* self);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
 ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-GType vala_symbol_accessibility_get_type (void);
 ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self);
-void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value);
 void vala_method_set_is_virtual (ValaMethod* self, gboolean value);
 void vala_method_set_vfunc_name (ValaMethod* self, const char* value);
 void vala_method_set_signal_reference (ValaMethod* self, ValaSignal* value);
@@ -466,13 +467,15 @@ ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_t
 	ValaDataType* actual_return_type;
 	ValaDelegate* generated_delegate;
 	ValaDataType* sender_param_type;
-	ValaDelegate* _tmp1;
+	ValaDelegate* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (sender_type != NULL, NULL);
 	g_return_val_if_fail (node_reference != NULL, NULL);
 	actual_return_type = vala_data_type_get_actual_type (vala_signal_get_return_type (self), sender_type, node_reference);
 	generated_delegate = vala_delegate_new (NULL, actual_return_type, NULL);
 	vala_delegate_set_has_target (generated_delegate, TRUE);
+	vala_symbol_set_access ((ValaSymbol*) generated_delegate, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	vala_symbol_set_owner ((ValaSymbol*) generated_delegate, vala_symbol_get_scope ((ValaSymbol*) self));
 	/* sender parameter is never null and doesn't own its value*/
 	sender_param_type = vala_data_type_copy (sender_type);
 	vala_data_type_set_value_owned (sender_param_type, FALSE);
@@ -484,12 +487,12 @@ ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_t
 		while (gee_iterator_next (_param_it)) {
 			ValaFormalParameter* param;
 			ValaFormalParameter* actual_param;
-			ValaDataType* _tmp0;
+			ValaDataType* _tmp0_;
 			param = (ValaFormalParameter*) gee_iterator_get (_param_it);
 			actual_param = vala_formal_parameter_copy (param);
-			_tmp0 = NULL;
-			vala_formal_parameter_set_parameter_type (actual_param, _tmp0 = vala_data_type_get_actual_type (vala_formal_parameter_get_parameter_type (actual_param), sender_type, node_reference));
-			(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL));
+			_tmp0_ = NULL;
+			vala_formal_parameter_set_parameter_type (actual_param, _tmp0_ = vala_data_type_get_actual_type (vala_formal_parameter_get_parameter_type (actual_param), sender_type, node_reference));
+			(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
 			vala_delegate_add_parameter (generated_delegate, actual_param);
 			(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
 			(actual_param == NULL) ? NULL : (actual_param = (vala_code_node_unref (actual_param), NULL));
@@ -497,8 +500,8 @@ ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_t
 		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
 	}
 	vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self), NULL, (ValaSymbol*) generated_delegate);
-	_tmp1 = NULL;
-	return (_tmp1 = generated_delegate, (actual_return_type == NULL) ? NULL : (actual_return_type = (vala_code_node_unref (actual_return_type), NULL)), (sender_param_type == NULL) ? NULL : (sender_param_type = (vala_code_node_unref (sender_param_type), NULL)), _tmp1);
+	_tmp1_ = NULL;
+	return (_tmp1_ = generated_delegate, (actual_return_type == NULL) ? NULL : (actual_return_type = (vala_code_node_unref (actual_return_type), NULL)), (sender_param_type == NULL) ? NULL : (sender_param_type = (vala_code_node_unref (sender_param_type), NULL)), _tmp1_);
 }
 
 
@@ -508,26 +511,26 @@ ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_t
  * @return the name to be used in C code
  */
 char* vala_signal_get_cname (ValaSignal* self) {
-	const char* _tmp1;
+	const char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->cname == NULL) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		self->priv->cname = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0);
+		char* _tmp0_;
+		_tmp0_ = NULL;
+		self->priv->cname = (_tmp0_ = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
 	}
-	_tmp1 = NULL;
-	return (_tmp1 = self->priv->cname, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1));
+	_tmp1_ = NULL;
+	return (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
 }
 
 
 void vala_signal_set_cname (ValaSignal* self, const char* cname) {
-	char* _tmp1;
-	const char* _tmp0;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (cname != NULL);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->cname = (_tmp1_ = (_tmp0_ = cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1_);
 }
 
 
@@ -539,31 +542,31 @@ void vala_signal_set_cname (ValaSignal* self, const char* cname) {
 ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self, const char* detail) {
 	GString* str;
 	char* i;
-	ValaCCodeConstant* _tmp2;
+	ValaCCodeConstant* _tmp2_;
 	g_return_val_if_fail (self != NULL, NULL);
 	str = g_string_new ("\"");
 	i = vala_signal_get_cname (self);
 	while (g_utf8_strlen (i, -1) > 0) {
 		gunichar c;
-		char* _tmp1;
-		const char* _tmp0;
+		char* _tmp1_;
+		const char* _tmp0_;
 		c = g_utf8_get_char (i);
 		if (c == '_') {
 			g_string_append_c (str, '-');
 		} else {
 			g_string_append_unichar (str, c);
 		}
-		_tmp1 = NULL;
-		_tmp0 = NULL;
-		i = (_tmp1 = (_tmp0 = g_utf8_next_char (i), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), i = (g_free (i), NULL), _tmp1);
+		_tmp1_ = NULL;
+		_tmp0_ = NULL;
+		i = (_tmp1_ = (_tmp0_ = g_utf8_next_char (i), (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), i = (g_free (i), NULL), _tmp1_);
 	}
 	if (detail != NULL) {
 		g_string_append (str, "::");
 		g_string_append (str, detail);
 	}
 	g_string_append_c (str, '"');
-	_tmp2 = NULL;
-	return (_tmp2 = vala_ccode_constant_new (str->str), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), i = (g_free (i), NULL), _tmp2);
+	_tmp2_ = NULL;
+	return (_tmp2_ = vala_ccode_constant_new (str->str), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), i = (g_free (i), NULL), _tmp2_);
 }
 
 
@@ -605,10 +608,10 @@ void vala_signal_process_attributes (ValaSignal* self) {
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp0;
+			ValaAttribute* _tmp0_;
 			ValaAttribute* a;
-			_tmp0 = NULL;
-			a = (_tmp0 = (ValaAttribute*) a_it->data, (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
+			_tmp0_ = NULL;
+			a = (_tmp0_ = (ValaAttribute*) a_it->data, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "HasEmitter") == 0) {
 					vala_signal_set_has_emitter (self, TRUE);
@@ -646,13 +649,13 @@ static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old
 
 
 ValaMethod* vala_signal_get_method_handler (ValaSignal* self) {
-	ValaMethod* _tmp1;
+	ValaMethod* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_assert (self->priv->_is_virtual);
 	if (self->priv->generated_method == NULL) {
-		ValaMethod* _tmp0;
-		_tmp0 = NULL;
-		self->priv->generated_method = (_tmp0 = vala_method_new (vala_symbol_get_name ((ValaSymbol*) self), vala_signal_get_return_type (self), vala_code_node_get_source_reference ((ValaCodeNode*) self)), (self->priv->generated_method == NULL) ? NULL : (self->priv->generated_method = (vala_code_node_unref (self->priv->generated_method), NULL)), _tmp0);
+		ValaMethod* _tmp0_;
+		_tmp0_ = NULL;
+		self->priv->generated_method = (_tmp0_ = vala_method_new (vala_symbol_get_name ((ValaSymbol*) self), vala_signal_get_return_type (self), vala_code_node_get_source_reference ((ValaCodeNode*) self)), (self->priv->generated_method == NULL) ? NULL : (self->priv->generated_method = (vala_code_node_unref (self->priv->generated_method), NULL)), _tmp0_);
 		vala_symbol_set_access ((ValaSymbol*) self->priv->generated_method, vala_symbol_get_access ((ValaSymbol*) self));
 		vala_method_set_is_virtual (self->priv->generated_method, TRUE);
 		vala_method_set_vfunc_name (self->priv->generated_method, vala_symbol_get_name ((ValaSymbol*) self));
@@ -670,8 +673,8 @@ ValaMethod* vala_signal_get_method_handler (ValaSignal* self) {
 		}
 		vala_scope_add (vala_symbol_get_scope (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), NULL, (ValaSymbol*) self->priv->generated_method);
 	}
-	_tmp1 = NULL;
-	return (_tmp1 = self->priv->generated_method, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+	_tmp1_ = NULL;
+	return (_tmp1_ = self->priv->generated_method, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
 }
 
 
@@ -707,12 +710,12 @@ ValaDataType* vala_signal_get_return_type (ValaSignal* self) {
 
 
 void vala_signal_set_return_type (ValaSignal* self, ValaDataType* value) {
-	ValaDataType* _tmp2;
-	ValaDataType* _tmp1;
+	ValaDataType* _tmp2_;
+	ValaDataType* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_return_type == NULL) ? NULL : (self->priv->_return_type = (vala_code_node_unref (self->priv->_return_type), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_return_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_return_type == NULL) ? NULL : (self->priv->_return_type = (vala_code_node_unref (self->priv->_return_type), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_return_type, (ValaCodeNode*) self);
 }
 
