@@ -20,22 +20,16 @@
  * 	Mathias Hasselmann <mathias.hasselmann@gmx.de>
  */
 
-#include <vapigen/valavapicheck.h>
-#include <vala/valacodecontext.h>
-#include <vala/valasourcefile.h>
-#include <gee/list.h>
-#include <gee/set.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <vala.h>
+#include <gee.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/arraylist.h>
-#include <gee/hashset.h>
 #include <gidlparser.h>
 #include <gidlmodule.h>
-#include <gee/collection.h>
 #include <gidlnode.h>
 #include <stdio.h>
-#include <vala/valasourcereference.h>
-#include <vala/valareport.h>
 #include <glib/gstdio.h>
 
 
@@ -59,8 +53,6 @@ struct _ValaVAPICheckClass {
 	GObjectClass parent_class;
 };
 
-
-
 struct _ValaVAPICheckPrivate {
 	ValaCodeContext* _context;
 	ValaSourceFile* _gidl;
@@ -69,6 +61,9 @@ struct _ValaVAPICheckPrivate {
 	GeeSet* _symbols;
 };
 
+
+
+GType vala_vapi_check_get_type (void);
 #define VALA_VAPI_CHECK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_VAPI_CHECK, ValaVAPICheckPrivate))
 enum  {
 	VALA_VAPI_CHECK_DUMMY_PROPERTY,
@@ -76,68 +71,84 @@ enum  {
 	VALA_VAPI_CHECK_GIDL,
 	VALA_VAPI_CHECK_METADATA
 };
-static ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char* gidlname, ValaCodeContext* context);
-static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context);
+static void vala_vapi_check_set_gidl (ValaVAPICheck* self, ValaSourceFile* value);
+static void vala_vapi_check_set_metadata (ValaVAPICheck* self, ValaSourceFile* value);
+static void vala_vapi_check_set_context (ValaVAPICheck* self, ValaCodeContext* value);
+ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context);
+ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char* gidlname, ValaCodeContext* context);
+ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context);
+ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self);
+static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name, GList* members);
 static void _g_list_free_g_idl_module_free (GList* self);
 static void vala_vapi_check_parse_gidl (ValaVAPICheck* self);
-static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, const char* separator);
 static char* vala_vapi_check_get_scope (ValaVAPICheck* self);
+static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, const char* separator);
 static void vala_vapi_check_enter_scope (ValaVAPICheck* self, const char* name);
 static void vala_vapi_check_leave_scope (ValaVAPICheck* self);
-static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name, GList* members);
+ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self);
 static gint vala_vapi_check_check_metadata (ValaVAPICheck* self);
-static gint vala_vapi_check_run (ValaVAPICheck* self);
+gint vala_vapi_check_run (ValaVAPICheck* self);
 static gint vala_vapi_check_main (char** args, int args_length1);
-static ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self);
-static void vala_vapi_check_set_context (ValaVAPICheck* self, ValaCodeContext* value);
-static ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self);
-static void vala_vapi_check_set_gidl (ValaVAPICheck* self, ValaSourceFile* value);
-static ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self);
-static void vala_vapi_check_set_metadata (ValaVAPICheck* self, ValaSourceFile* value);
+ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self);
 static gpointer vala_vapi_check_parent_class = NULL;
 static void vala_vapi_check_finalize (GObject* obj);
-static GType vala_vapi_check_get_type (void);
+static void vala_vapi_check_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
+static void vala_vapi_check_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 
 
 
-static ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char* gidlname, ValaCodeContext* context) {
+static char* string_substring (const char* self, glong offset, glong len) {
+	glong string_length;
+	const char* start;
+	g_return_val_if_fail (self != NULL, NULL);
+	string_length = g_utf8_strlen (self, -1);
+	if (offset < 0) {
+		offset = string_length + offset;
+		g_return_val_if_fail (offset >= 0, NULL);
+	} else {
+		g_return_val_if_fail (offset <= string_length, NULL);
+	}
+	if (len < 0) {
+		len = string_length - offset;
+	}
+	g_return_val_if_fail ((offset + len) <= string_length, NULL);
+	start = g_utf8_offset_to_pointer (self, offset);
+	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+}
+
+
+ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char* gidlname, ValaCodeContext* context) {
 	GParameter * __params;
 	GParameter * __params_it;
-	ValaSourceFile* _tmp1;
-	ValaCodeContext* _tmp0;
-	ValaSourceFile* _tmp5;
-	char* _tmp4;
-	char* _tmp3;
-	char* _tmp2;
+	ValaSourceFile* _tmp1_;
+	ValaCodeContext* _tmp0_;
+	ValaSourceFile* _tmp4_;
+	char* _tmp3_;
+	char* _tmp2_;
 	ValaVAPICheck * self;
 	g_return_val_if_fail (gidlname != NULL, NULL);
 	g_return_val_if_fail (context != NULL, NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
-	_tmp1 = NULL;
-	_tmp0 = NULL;
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
 	__params_it->name = "gidl";
 	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	vala_value_set_source_file (&__params_it->value, _tmp1 = vala_source_file_new (context, gidlname, FALSE, NULL));
-	__params_it++;
-	(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_source_file_unref (_tmp1), NULL));
-	(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_context_unref (_tmp0), NULL));
-	_tmp5 = NULL;
-	_tmp4 = NULL;
-	_tmp3 = NULL;
-	_tmp2 = NULL;
-	__params_it->name = "metadata";
-	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	vala_value_set_source_file (&__params_it->value, _tmp5 = vala_source_file_new (context, _tmp4 = g_strconcat (_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (gidlname, (glong) 0), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidlname, -1) - 5) - _tmp2)), ".metadata", NULL), FALSE, NULL));
-	__params_it++;
-	(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_source_file_unref (_tmp5), NULL));
-	_tmp4 = (g_free (_tmp4), NULL);
-	_tmp3 = (g_free (_tmp3), NULL);
-	__params_it->name = "context";
-	g_value_init (&__params_it->value, VALA_TYPE_CODE_CONTEXT);
-	vala_value_set_code_context (&__params_it->value, context);
+	vala_value_set_source_file (&__params_it->value, _tmp1_ = vala_source_file_new (context, gidlname, FALSE, NULL));
 	__params_it++;
+	(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_source_file_unref (_tmp1_), NULL));
+	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_context_unref (_tmp0_), NULL));
+	_tmp4_ = NULL;
+	_tmp3_ = NULL;
+	_tmp2_ = NULL;
+	vala_vapi_check_set_metadata (self, _tmp4_ = vala_source_file_new (context, _tmp3_ = g_strconcat (_tmp2_ = string_substring (gidlname, (glong) 0, g_utf8_strlen (gidlname, -1) - 5), ".metadata", NULL), FALSE, NULL));
+	(_tmp4_ == NULL) ? NULL : (_tmp4_ = (vala_source_file_unref (_tmp4_), NULL));
+	_tmp3_ = (g_free (_tmp3_), NULL);
+	_tmp2_ = (g_free (_tmp2_), NULL);
+	vala_vapi_check_set_context (self, context);
 	self = g_object_newv (object_type, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -148,7 +159,7 @@ static ValaVAPICheck* vala_vapi_check_construct (GType object_type, const char*
 }
 
 
-static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context) {
+ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context) {
 	return vala_vapi_check_construct (VALA_TYPE_VAPI_CHECK, gidlname, context);
 }
 
@@ -160,29 +171,28 @@ static void _g_list_free_g_idl_module_free (GList* self) {
 
 
 static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
-	GError * inner_error;
-	GeeList* _tmp0;
-	GeeSet* _tmp1;
+	GError * _inner_error_;
+	GeeList* _tmp0_;
+	GeeSet* _tmp1_;
 	g_return_if_fail (self != NULL);
-	inner_error = NULL;
-	_tmp0 = NULL;
-	self->priv->_scope = (_tmp0 = (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal), (self->priv->_scope == NULL) ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL)), _tmp0);
-	_tmp1 = NULL;
-	self->priv->_symbols = (_tmp1 = (GeeSet*) gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_str_hash, g_str_equal), (self->priv->_symbols == NULL) ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL)), _tmp1);
+	_inner_error_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_scope = (_tmp0_ = (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal), (self->priv->_scope == NULL) ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL)), _tmp0_);
+	_tmp1_ = NULL;
+	self->priv->_symbols = (_tmp1_ = (GeeSet*) gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_str_hash, g_str_equal), (self->priv->_symbols == NULL) ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL)), _tmp1_);
 	{
-		GList* _tmp2;
-		_tmp2 = g_idl_parse_file (vala_source_file_get_filename (self->priv->_gidl), &inner_error);
-		if (inner_error != NULL) {
-			if (inner_error->domain == G_MARKUP_ERROR) {
+		GList* _tmp2_;
+		_tmp2_ = g_idl_parse_file (vala_source_file_get_filename (self->priv->_gidl), &_inner_error_);
+		if (_inner_error_ != NULL) {
+			if (_inner_error_->domain == G_MARKUP_ERROR) {
 				goto __catch0_g_markup_error;
 			}
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+			goto __finally0;
 		}
 		{
 			GList* module_collection;
 			GList* module_it;
-			module_collection = _tmp2;
+			module_collection = _tmp2_;
 			for (module_it = module_collection; module_it != NULL; module_it = module_it->next) {
 				GIdlModule* module;
 				module = (GIdlModule*) module_it->data;
@@ -197,15 +207,19 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 	__catch0_g_markup_error:
 	{
 		GError * e;
-		e = inner_error;
-		inner_error = NULL;
+		e = _inner_error_;
+		_inner_error_ = NULL;
 		{
 			fprintf (stderr, "%s: %s\n", vala_source_file_get_filename (self->priv->_gidl), e->message);
 			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 		}
 	}
 	__finally0:
-	;
+	if (_inner_error_ != NULL) {
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+		g_clear_error (&_inner_error_);
+		return;
+	}
 }
 
 
@@ -213,14 +227,14 @@ static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, c
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (name != NULL);
 	if (NULL != separator) {
-		char* _tmp1;
-		char* _tmp0;
-		char* _tmp2;
+		char* _tmp1_;
+		char* _tmp0_;
+		char* _tmp2_;
 		char* fullname;
-		_tmp1 = NULL;
-		_tmp0 = NULL;
-		_tmp2 = NULL;
-		fullname = (_tmp2 = g_strconcat (_tmp1 = g_strconcat (_tmp0 = vala_vapi_check_get_scope (self), separator, NULL), name, NULL), _tmp1 = (g_free (_tmp1), NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
+		_tmp1_ = NULL;
+		_tmp0_ = NULL;
+		_tmp2_ = NULL;
+		fullname = (_tmp2_ = g_strconcat (_tmp1_ = g_strconcat (_tmp0_ = vala_vapi_check_get_scope (self), separator, NULL), name, NULL), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp2_);
 		gee_collection_add ((GeeCollection*) self->priv->_symbols, fullname);
 		fullname = (g_free (fullname), NULL);
 	} else {
@@ -231,7 +245,7 @@ static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, c
 
 static char* vala_vapi_check_get_scope (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, NULL);
-	return (char*) gee_list_get ((GeeList*) self->priv->_scope, gee_collection_get_size ((GeeCollection*) self->priv->_scope) - 1);
+	return (char*) gee_list_get (self->priv->_scope, gee_collection_get_size ((GeeCollection*) self->priv->_scope) - 1);
 }
 
 
@@ -252,7 +266,6 @@ static void vala_vapi_check_leave_scope (ValaVAPICheck* self) {
 static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name, GList* members) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (name != NULL);
-	g_return_if_fail (members != NULL);
 	vala_vapi_check_enter_scope (self, name);
 	{
 		GList* node_collection;
@@ -320,107 +333,114 @@ static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name
 
 
 static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
-	GError * inner_error;
+	GError * _inner_error_;
 	g_return_val_if_fail (self != NULL, 0);
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	{
 		GIOChannel* metafile;
 		char* line;
 		gint lineno;
-		gint _tmp8;
-		metafile = g_io_channel_new_file (vala_source_file_get_filename (self->priv->_metadata), "r", &inner_error);
-		if (inner_error != NULL) {
-			if (inner_error->domain == G_FILE_ERROR) {
+		gint _tmp9_;
+		metafile = g_io_channel_new_file (vala_source_file_get_filename (self->priv->_metadata), "r", &_inner_error_);
+		if (_inner_error_ != NULL) {
+			if (_inner_error_->domain == G_FILE_ERROR) {
 				goto __catch1_g_file_error;
 			}
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+			goto __finally1;
 		}
 		line = NULL;
 		lineno = 1;
 		while (TRUE) {
-			char* _tmp2;
-			GIOStatus _tmp1;
-			char* _tmp0;
-			GIOStatus _tmp3;
-			char** _tmp4;
+			char* _tmp2_;
+			GIOStatus _tmp1_;
+			char* _tmp0_;
+			GIOStatus _tmp3_;
+			char** _tmp5_;
+			gint tokens_size;
 			gint tokens_length1;
+			char** _tmp4_;
 			char** tokens;
-			const char* _tmp5;
+			const char* _tmp6_;
 			char* symbol;
-			gboolean _tmp6;
-			_tmp2 = NULL;
-			_tmp0 = NULL;
-			_tmp3 = (_tmp1 = g_io_channel_read_line (metafile, &_tmp0, NULL, NULL, &inner_error), line = (_tmp2 = _tmp0, line = (g_free (line), NULL), _tmp2), _tmp1);
-			if (inner_error != NULL) {
-				if (inner_error->domain == G_FILE_ERROR) {
+			gboolean _tmp7_;
+			_tmp2_ = NULL;
+			_tmp0_ = NULL;
+			_tmp3_ = (_tmp1_ = g_io_channel_read_line (metafile, &_tmp0_, NULL, NULL, &_inner_error_), line = (_tmp2_ = _tmp0_, line = (g_free (line), NULL), _tmp2_), _tmp1_);
+			if (_inner_error_ != NULL) {
+				(metafile == NULL) ? NULL : (metafile = (g_io_channel_unref (metafile), NULL));
+				line = (g_free (line), NULL);
+				if (_inner_error_->domain == G_FILE_ERROR) {
 					goto __catch1_g_file_error;
 				}
-				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-				g_clear_error (&inner_error);
+				goto __finally1;
 			}
-			if (!(G_IO_STATUS_NORMAL == _tmp3)) {
+			if (!(G_IO_STATUS_NORMAL == _tmp3_)) {
 				break;
 			}
-			_tmp4 = NULL;
-			tokens = (_tmp4 = g_strsplit (line, " ", 2), tokens_length1 = -1, _tmp4);
-			_tmp5 = NULL;
-			symbol = (_tmp5 = tokens[0], (_tmp5 == NULL) ? NULL : g_strdup (_tmp5));
-			_tmp6 = FALSE;
+			_tmp5_ = NULL;
+			_tmp4_ = NULL;
+			tokens = (_tmp5_ = _tmp4_ = g_strsplit (line, " ", 2), tokens_length1 = _vala_array_length (_tmp4_), tokens_size = tokens_length1, _tmp5_);
+			_tmp6_ = NULL;
+			symbol = (_tmp6_ = tokens[0], (_tmp6_ == NULL) ? NULL : g_strdup (_tmp6_));
+			_tmp7_ = FALSE;
 			if (strlen (symbol) > 0) {
-				_tmp6 = !gee_collection_contains ((GeeCollection*) self->priv->_symbols, symbol);
+				_tmp7_ = !gee_collection_contains ((GeeCollection*) self->priv->_symbols, symbol);
 			} else {
-				_tmp6 = FALSE;
+				_tmp7_ = FALSE;
 			}
-			if (_tmp6) {
+			if (_tmp7_) {
 				ValaSourceReference* src;
-				char* _tmp7;
+				char* _tmp8_;
 				src = vala_source_reference_new (self->priv->_metadata, lineno, 1, lineno, (gint) g_utf8_strlen (symbol, -1));
-				_tmp7 = NULL;
-				vala_report_error (src, _tmp7 = g_strdup_printf ("Symbol `%s' not found", symbol));
-				_tmp7 = (g_free (_tmp7), NULL);
+				_tmp8_ = NULL;
+				vala_report_error (src, _tmp8_ = g_strdup_printf ("Symbol `%s' not found", symbol));
+				_tmp8_ = (g_free (_tmp8_), NULL);
 				(src == NULL) ? NULL : (src = (vala_source_reference_unref (src), NULL));
 			}
-			lineno = lineno + (1);
+			lineno = lineno + 1;
 			tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
 			symbol = (g_free (symbol), NULL);
 		}
-		return (_tmp8 = 0, (metafile == NULL) ? NULL : (metafile = (g_io_channel_unref (metafile), NULL)), line = (g_free (line), NULL), _tmp8);
+		return (_tmp9_ = 0, (metafile == NULL) ? NULL : (metafile = (g_io_channel_unref (metafile), NULL)), line = (g_free (line), NULL), _tmp9_);
 	}
 	goto __finally1;
 	__catch1_g_file_error:
 	{
-		GError * error;
-		error = inner_error;
-		inner_error = NULL;
+		GError * _error_;
+		_error_ = _inner_error_;
+		_inner_error_ = NULL;
 		{
-			char* _tmp9;
-			gint _tmp10;
-			_tmp9 = NULL;
-			vala_report_error (NULL, _tmp9 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (self->priv->_metadata), error->message));
-			_tmp9 = (g_free (_tmp9), NULL);
-			return (_tmp10 = 1, (error == NULL) ? NULL : (error = (g_error_free (error), NULL)), _tmp10);
+			char* _tmp10_;
+			gint _tmp11_;
+			_tmp10_ = NULL;
+			vala_report_error (NULL, _tmp10_ = g_strdup_printf ("%s: %s", vala_source_file_get_filename (self->priv->_metadata), _error_->message));
+			_tmp10_ = (g_free (_tmp10_), NULL);
+			return (_tmp11_ = 1, (_error_ == NULL) ? NULL : (_error_ = (g_error_free (_error_), NULL)), _tmp11_);
 		}
 	}
 	__finally1:
-	;
+	if (_inner_error_ != NULL) {
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+		g_clear_error (&_inner_error_);
+		return 0;
+	}
 }
 
 
-static gint vala_vapi_check_run (ValaVAPICheck* self) {
+gint vala_vapi_check_run (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, 0);
 	if (!g_file_test (vala_source_file_get_filename (self->priv->_gidl), G_FILE_TEST_IS_REGULAR)) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		vala_report_error (NULL, _tmp0 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_gidl)));
-		_tmp0 = (g_free (_tmp0), NULL);
+		char* _tmp0_;
+		_tmp0_ = NULL;
+		vala_report_error (NULL, _tmp0_ = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_gidl)));
+		_tmp0_ = (g_free (_tmp0_), NULL);
 		return 2;
 	}
 	if (!g_file_test (vala_source_file_get_filename (self->priv->_metadata), G_FILE_TEST_IS_REGULAR)) {
-		char* _tmp2;
-		_tmp2 = NULL;
-		vala_report_error (NULL, _tmp2 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_metadata)));
-		_tmp2 = (g_free (_tmp2), NULL);
+		char* _tmp2_;
+		_tmp2_ = NULL;
+		vala_report_error (NULL, _tmp2_ = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_metadata)));
+		_tmp2_ = (g_free (_tmp2_), NULL);
 		return 2;
 	}
 	vala_vapi_check_parse_gidl (self);
@@ -429,28 +449,28 @@ static gint vala_vapi_check_run (ValaVAPICheck* self) {
 
 
 static gint vala_vapi_check_main (char** args, int args_length1) {
-	gboolean _tmp0;
-	ValaCodeContext* _tmp3;
-	ValaVAPICheck* _tmp4;
+	gboolean _tmp0_;
+	ValaCodeContext* _tmp3_;
+	ValaVAPICheck* _tmp4_;
 	ValaVAPICheck* vapicheck;
-	gint _tmp5;
-	_tmp0 = FALSE;
+	gint _tmp5_;
+	_tmp0_ = FALSE;
 	if (2 != args_length1) {
-		_tmp0 = TRUE;
+		_tmp0_ = TRUE;
 	} else {
-		_tmp0 = !g_str_has_suffix (args[1], ".gidl");
+		_tmp0_ = !g_str_has_suffix (args[1], ".gidl");
 	}
-	if (_tmp0) {
-		char* _tmp1;
-		_tmp1 = NULL;
-		fprintf (stdout, "Usage: %s library.gidl\n", _tmp1 = g_path_get_basename (args[0]));
-		_tmp1 = (g_free (_tmp1), NULL);
+	if (_tmp0_) {
+		char* _tmp1_;
+		_tmp1_ = NULL;
+		fprintf (stdout, "Usage: %s library.gidl\n", _tmp1_ = g_path_get_basename (args[0]));
+		_tmp1_ = (g_free (_tmp1_), NULL);
 		return 2;
 	}
-	_tmp3 = NULL;
-	_tmp4 = NULL;
-	vapicheck = (_tmp4 = vala_vapi_check_new (args[1], _tmp3 = vala_code_context_new ()), (_tmp3 == NULL) ? NULL : (_tmp3 = (vala_code_context_unref (_tmp3), NULL)), _tmp4);
-	return (_tmp5 = vala_vapi_check_run (vapicheck), (vapicheck == NULL) ? NULL : (vapicheck = (g_object_unref (vapicheck), NULL)), _tmp5);
+	_tmp3_ = NULL;
+	_tmp4_ = NULL;
+	vapicheck = (_tmp4_ = vala_vapi_check_new (args[1], _tmp3_ = vala_code_context_new ()), (_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_context_unref (_tmp3_), NULL)), _tmp4_);
+	return (_tmp5_ = vala_vapi_check_run (vapicheck), (vapicheck == NULL) ? NULL : (vapicheck = (g_object_unref (vapicheck), NULL)), _tmp5_);
 }
 
 
@@ -460,59 +480,99 @@ int main (int argc, char ** argv) {
 }
 
 
-static ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self) {
+ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_context;
 }
 
 
 static void vala_vapi_check_set_context (ValaVAPICheck* self, ValaCodeContext* value) {
-	ValaCodeContext* _tmp2;
-	ValaCodeContext* _tmp1;
+	ValaCodeContext* _tmp2_;
+	ValaCodeContext* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_context = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_context_ref (_tmp1)), (self->priv->_context == NULL) ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_context = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_context_ref (_tmp1_)), (self->priv->_context == NULL) ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL)), _tmp2_);
 	g_object_notify ((GObject *) self, "context");
 }
 
 
-static ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self) {
+ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_gidl;
 }
 
 
 static void vala_vapi_check_set_gidl (ValaVAPICheck* self, ValaSourceFile* value) {
-	ValaSourceFile* _tmp2;
-	ValaSourceFile* _tmp1;
+	ValaSourceFile* _tmp2_;
+	ValaSourceFile* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_gidl = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_source_file_ref (_tmp1)), (self->priv->_gidl == NULL) ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_gidl = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_source_file_ref (_tmp1_)), (self->priv->_gidl == NULL) ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL)), _tmp2_);
 	g_object_notify ((GObject *) self, "gidl");
 }
 
 
-static ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self) {
+ValaSourceFile* vala_vapi_check_get_metadata (ValaVAPICheck* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_metadata;
 }
 
 
 static void vala_vapi_check_set_metadata (ValaVAPICheck* self, ValaSourceFile* value) {
-	ValaSourceFile* _tmp2;
-	ValaSourceFile* _tmp1;
+	ValaSourceFile* _tmp2_;
+	ValaSourceFile* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_metadata = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_source_file_ref (_tmp1)), (self->priv->_metadata == NULL) ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_metadata = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_source_file_ref (_tmp1_)), (self->priv->_metadata == NULL) ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL)), _tmp2_);
 	g_object_notify ((GObject *) self, "metadata");
 }
 
 
+static void vala_vapi_check_class_init (ValaVAPICheckClass * klass) {
+	vala_vapi_check_parent_class = g_type_class_peek_parent (klass);
+	g_type_class_add_private (klass, sizeof (ValaVAPICheckPrivate));
+	G_OBJECT_CLASS (klass)->get_property = vala_vapi_check_get_property;
+	G_OBJECT_CLASS (klass)->set_property = vala_vapi_check_set_property;
+	G_OBJECT_CLASS (klass)->finalize = vala_vapi_check_finalize;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_CONTEXT, vala_param_spec_code_context ("context", "context", "context", VALA_TYPE_CODE_CONTEXT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_GIDL, vala_param_spec_source_file ("gidl", "gidl", "gidl", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_METADATA, vala_param_spec_source_file ("metadata", "metadata", "metadata", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+}
+
+
+static void vala_vapi_check_instance_init (ValaVAPICheck * self) {
+	self->priv = VALA_VAPI_CHECK_GET_PRIVATE (self);
+}
+
+
+static void vala_vapi_check_finalize (GObject* obj) {
+	ValaVAPICheck * self;
+	self = VALA_VAPI_CHECK (obj);
+	(self->priv->_context == NULL) ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL));
+	(self->priv->_gidl == NULL) ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL));
+	(self->priv->_metadata == NULL) ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL));
+	(self->priv->_scope == NULL) ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL));
+	(self->priv->_symbols == NULL) ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL));
+	G_OBJECT_CLASS (vala_vapi_check_parent_class)->finalize (obj);
+}
+
+
+GType vala_vapi_check_get_type (void) {
+	static GType vala_vapi_check_type_id = 0;
+	if (vala_vapi_check_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPICheckClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_check_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPICheck), 0, (GInstanceInitFunc) vala_vapi_check_instance_init, NULL };
+		vala_vapi_check_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaVAPICheck", &g_define_type_info, 0);
+	}
+	return vala_vapi_check_type_id;
+}
+
+
 static void vala_vapi_check_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaVAPICheck * self;
+	gpointer boxed;
 	self = VALA_VAPI_CHECK (object);
 	switch (property_id) {
 		case VALA_VAPI_CHECK_CONTEXT:
@@ -551,59 +611,33 @@ static void vala_vapi_check_set_property (GObject * object, guint property_id, c
 }
 
 
-static void vala_vapi_check_class_init (ValaVAPICheckClass * klass) {
-	vala_vapi_check_parent_class = g_type_class_peek_parent (klass);
-	g_type_class_add_private (klass, sizeof (ValaVAPICheckPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_vapi_check_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_vapi_check_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_vapi_check_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_CONTEXT, vala_param_spec_code_context ("context", "context", "context", VALA_TYPE_CODE_CONTEXT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_GIDL, vala_param_spec_source_file ("gidl", "gidl", "gidl", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VAPI_CHECK_METADATA, vala_param_spec_source_file ("metadata", "metadata", "metadata", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-}
-
-
-static void vala_vapi_check_instance_init (ValaVAPICheck * self) {
-	self->priv = VALA_VAPI_CHECK_GET_PRIVATE (self);
-}
-
-
-static void vala_vapi_check_finalize (GObject* obj) {
-	ValaVAPICheck * self;
-	self = VALA_VAPI_CHECK (obj);
-	(self->priv->_context == NULL) ? NULL : (self->priv->_context = (vala_code_context_unref (self->priv->_context), NULL));
-	(self->priv->_gidl == NULL) ? NULL : (self->priv->_gidl = (vala_source_file_unref (self->priv->_gidl), NULL));
-	(self->priv->_metadata == NULL) ? NULL : (self->priv->_metadata = (vala_source_file_unref (self->priv->_metadata), NULL));
-	(self->priv->_scope == NULL) ? NULL : (self->priv->_scope = (gee_collection_object_unref (self->priv->_scope), NULL));
-	(self->priv->_symbols == NULL) ? NULL : (self->priv->_symbols = (gee_collection_object_unref (self->priv->_symbols), NULL));
-	G_OBJECT_CLASS (vala_vapi_check_parent_class)->finalize (obj);
-}
-
-
-static GType vala_vapi_check_get_type (void) {
-	static GType vala_vapi_check_type_id = 0;
-	if (vala_vapi_check_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPICheckClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_check_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPICheck), 0, (GInstanceInitFunc) vala_vapi_check_instance_init, NULL };
-		vala_vapi_check_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaVAPICheck", &g_define_type_info, 0);
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	if ((array != NULL) && (destroy_func != NULL)) {
+		int i;
+		for (i = 0; i < array_length; i = i + 1) {
+			if (((gpointer*) array)[i] != NULL) {
+				destroy_func (((gpointer*) array)[i]);
+			}
+		}
 	}
-	return vala_vapi_check_type_id;
 }
 
 
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
-	if ((array != NULL) && (destroy_func != NULL)) {
-		int i;
-		if (array_length >= 0)
-		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
-		}
-		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+	_vala_array_destroy (array, array_length, destroy_func);
+	g_free (array);
+}
+
+
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
 		}
 	}
-	g_free (array);
+	return length;
 }
 
 
